@@ -7,7 +7,7 @@ BEGIN { require Fennec::Runner }
 use Fennec::Test;
 use Fennec::Util qw/inject_sub require_module verbose_message/;
 use Carp qw/croak carp/;
-our $VERSION = '2.008';
+our $VERSION = '2.009';
 
 sub defaults {
     (
@@ -65,6 +65,24 @@ sub import {
     $class->_process_deps( $runner, $params{skip_without} );
     $class->_set_isa( $importer, 'Fennec::Test', $meta->base );
     $class->_load_utils( $importer, %params );
+
+    # Intercept Mock::Quick mocks
+    my $wfmeta = $importer->TEST_WORKFLOW;
+    if ( $wfmeta && grep { $_ eq 'Mock::Quick' } @{$defaults{utils} || []}) {
+        my $intercept = sub {
+            my ($code) = @_;
+            my @caller = caller;
+
+            my $store = $wfmeta->control_store;
+            return push @$store => $code->() if $store;
+
+            my $layer = $wfmeta->peek_layer || $wfmeta->root_layer;
+            $layer->add_control($code);
+        };
+        no strict 'refs';
+        *{"$importer\::QINTERCEPT"} = sub{ $intercept };
+    }
+
     $class->_with_tests( $importer, $params{with_tests} );
     $class->init( %params, importer => $importer, meta => $meta );
 
@@ -875,6 +893,57 @@ See L<Mock::Quick> for more details
 
     # use qstrict() to make an object that does not autovivify accessors.
 
+=head3 SCOPE OF MOCKS IN FENNEC
+
+With vanilla L<Mock::Quick> a mock is destroyed when the control object is destroyed.
+
+    my $control = qtakeover Foo => (blah => 'blah');
+    is( Foo->blah, 'blah', "got mock" );
+    $control = undef;
+    ok( !Foo->can('blah'), "Mock destroyed" );
+
+    # WITHOUT FENNEC This issues a warning, the $control object is ignored so
+    # the mock is destroyed before it can be used.
+    qtakover Foo => (blah => 'blah');
+    ok( !Foo->can('blah'), "Mock destroyed before it could be used" );
+
+With the workflow support provided by Fennec, you can omit the control object
+and let the mock be scoped implicitly.
+
+    tests implicit_mock_scope => sub {
+        my $self = shift;
+        can_ok( $self, 'QINTERCEPT' );
+        qtakeover Foo => (blah => sub { 'blah' });
+        is( Foo->blah, 'blah', "Mock not auto-destroyed" );
+    };
+
+    describe detailed_implicit_mock_scope => sub {
+        qtakeover Foo => ( outer => 'outer' );
+        ok( !Foo->can( 'outer' ), "No Leak" );
+
+        before_all ba => sub {
+            qtakeover Foo => ( ba => 'ba' );
+            can_ok( 'Foo', qw/outer ba/ );
+        };
+
+        before_each be => sub {
+            qtakeover Foo => ( be => 'be' );
+            can_ok( 'Foo', qw/outer ba be/ );
+        };
+
+        tests the_check => sub {
+            qtakeover Foo => ( inner => 'inner' );
+
+            can_ok( 'Foo', qw/outer ba be inner/ );
+        };
+
+        ok( !Foo->can( 'outer' ), "No Leak" );
+        ok( !Foo->can( 'ba' ), "No Leak" );
+        ok( !Foo->can( 'be' ), "No Leak" );
+        ok( !Foo->can( 'inner' ), "No Leak" );
+    };
+
+
 =head3 TAKEOVER AN EXISTING CLASS
 
     require Some::Class;
